local addonName, BGRep = ...
local AceAddon = LibStub("AceAddon-3.0")
BGRep = LibStub("AceAddon-3.0"):NewAddon(BGRep, addonName, "AceEvent-3.0")
local db

local warsongFlags = 0
local arathiTicks = 0
local warsongID = 0
local arathiID = 0
local maxValue = 42000

-- Default DB settings
local defaults = {
	profile = {
		bgrepPoint = "CENTER",
		bgrepRelativeTo = nil,
		bgrepRelativePoint = "CENTER",
		bgrepxOfs = 0,
		bgrepyOfs = 0,
	}
}

function BGRep:FactionCheck()
	englishFaction, localizedFaction = UnitFactionGroup(UnitName("player"))
	if englishFaction == "Horde" then
		warsongID = 889
		arathiID = 510
	elseif englishFaction == "Alliance" then
		warsongID = 890
		arathiID = 509
	end
end

function BGRep:OnDragStart(arg1)
	if arg1 == "LeftButton" then
		self:StartMoving()
	end
end

function BGRep:OnDragStop()
	self:StopMovingOrSizing()
	
	point, relativeTo, relativePoint, xOfs, yOfs = frame:GetPoint()
	
	db.bgrepPoint = point
	db.bgrepRelativeTo = relativeTo
	db.bgrepRelativePoint = relativePoint
	db.bgrepxOfs = xOfs
	db.bgrepyOfs = yOfs
end

function BGRep:SetupFrame()
	frame = CreateFrame("Frame", "MainFrame", UIParent)
	frame:SetMovable(true)
	frame:EnableMouse(true)
	frame:RegisterForDrag("LeftButton")
	frame:SetScript("OnMouseDown", BGRep.OnDragStart)
	frame:SetScript("OnMouseUp", BGRep.OnDragStop)
	
	frame:SetPoint(db.bgrepPoint, db.bgrepRelativeTo, db.bgrepRelativePoint, db.bgrepxOfs, db.bgrepyOfs);
	frame:SetWidth(128);
	frame:SetHeight(45);
	local tex = frame:CreateTexture("ARTWORK");
	tex:SetAllPoints();
	tex:SetTexture(1.0, 0.5, 0); tex:SetAlpha(0.5);
	
	--Warsong Gulch Text
	frame.Warsong = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	frame.Warsong:SetPoint("TOP", frame, "TOP", 0, -5)
	frame.Warsong:SetTextColor(1.0, 1.0, 1.0)
	frame.Warsong:SetText("Warsong Gulch: " .. warsongFlags)
	
	--Arathi Basin Text
	frame.Arathi = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	frame.Arathi:SetPoint("TOP", frame, "TOP", 0, -25)
	frame.Arathi:SetTextColor(1.0, 1.0, 1.0)
	frame.Arathi:SetText("Arathi Basin: " .. arathiTicks)
	
	frame:Hide()
end

function BGRep:FlagUpdate()
	local name, description, standingID, barMin, barMax, barValue = GetFactionInfoByID(warsongID)
	warsongFlags = math.floor((maxValue - barValue) / 100 + 0.5)
	
	name, description, standingID, barMin, barMax, barValue = GetFactionInfoByID(arathiID)
	arathiTicks = math.floor((maxValue - barValue) / 50 + 0.5)
	
	frame.Warsong:SetText("Warsong Gulch: " .. warsongFlags)
	frame.Arathi:SetText("Arathi Basin: " .. arathiTicks)
end

function BGRep:OnInitialize()
	-- Initialize the DB
	self.db = LibStub("AceDB-3.0"):New("BGRepDB", defaults, true)
	db = self.db.profile
	
	BGRep.SetupFrame()
end

function BGRep:Enable()
	if not SecondTime then
		BGRep.FactionCheck()
		BGRep.FlagUpdate()
		SecondTime = true
	end
	BGRep:RegisterEvent("CHAT_MSG_COMBAT_FACTION_CHANGE", BGRep.FlagUpdate)
	frame:Show()
end

function BGRep:Disable()
	BGRep:UnregisterEvent("CHAT_MSG_COMBAT_FACTION_CHANGE", BGRep.FlagUpdate)
	frame:Hide()
end

function BGRep:Toggle()
	if frame:IsShown() then
		BGRep:Disable()
	else
		BGRep:Enable()
	end
end